@@ -33,6 +33,7 @@
 #include <libxml/xmlmemory.h>
 #include <pango/pango.h>
 #include <glib/gslist.h>
+#include <glib-object.h>
 #include <math.h>
 
 G_BEGIN_DECLS
@@ -72,9 +73,16 @@ struct RsvgSaxHandler {
 	void (*characters) (RsvgSaxHandler *self, const xmlChar *ch, int len);
 };
 
+struct RsvgHandleClass {
+	GObjectClass parent;
+};
+
 /* Contextual information for the parsing phase*/
 
 struct RsvgHandle {
+	GObject parent;
+	gboolean is_disposed;
+
 	RsvgSizeFunc size_func;
 	gpointer user_data;
 	GDestroyNotify user_data_destroy;
@@ -135,6 +143,7 @@ struct RsvgDrawingCtx {
 	double dpi_x, dpi_y;
 	RsvgViewBox vb;
 	GSList * vb_stack;
+	GSList * drawsub_stack;
 };
 
 /*Abstract base class for context for our backends (one as yet)*/
@@ -190,6 +199,9 @@ struct RsvgSizeCallbackData
 
 	gboolean keep_aspect_ratio;
 };
+void _rsvg_size_callback (int *width,
+						  int *height,
+						  gpointer  data);
 
 struct _RsvgPropertyBag
 {
@@ -335,6 +347,8 @@ _rsvg_css_parse_length(const char *str);
 void _rsvg_push_view_box(RsvgDrawingCtx *ctx, double w, double h);
 void _rsvg_pop_view_box(RsvgDrawingCtx *ctx);
 
+void rsvg_SAX_handler_struct_init (void);
+
 G_END_DECLS
 
 #endif
