@@ -29,20 +29,57 @@
 
 G_BEGIN_DECLS
 
+#define RSVG_TYPE_HANDLE                  (rsvg_handle_get_type ())
+#define RSVG_HANDLE(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), RSVG_TYPE_HANDLE, RsvgHandle))
+#define RSVG_HANDLE_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), RSVG_TYPE_HANDLE, RsvgHandleClass))
+#define RSVG_IS_HANDLE(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RSVG_TYPE_HANDLE))
+#define RSVG_IS_HANDLE_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), RSVG_TYPE_HANDLE))
+#define RSVG_HANDLE_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), RSVG_TYPE_HANDLE, RsvgHandleClass))
+
+GType rsvg_handle_get_type (void);
+
+/**
+ * An enumeration representing possible error domains
+ */
 typedef enum {
 	RSVG_ERROR_FAILED
 } RsvgError;
 
+/**
+ * 
+ */
 #define RSVG_ERROR (rsvg_error_quark ())
 GQuark rsvg_error_quark (void) G_GNUC_CONST;
 
+/**
+ * The RsvgHandle is an object representing the parsed form of a SVG
+ */
 typedef struct RsvgHandle RsvgHandle;
+typedef struct RsvgHandleClass RsvgHandleClass;
+typedef struct _RsvgDimensionData RsvgDimensionData;
 
-typedef struct RsvgDimensionData RsvgDimensionData;
-struct RsvgDimensionData {
+/* RsvgDimensionData
+ */
+struct _RsvgDimensionData {
+	/**
+	 * SVG's width, in pixels
+	 */
 	int width;
+
+	/**
+	 * SVG's height, in pixels
+	 */
 	int height;
-	gdouble em, ex;
+
+	/**
+	 * em
+	 */
+	gdouble em;
+
+	/**
+	 * ex
+	 */
+	gdouble ex;
 };
 
 void        rsvg_init (void);
@@ -63,7 +100,6 @@ gboolean    rsvg_handle_close             (RsvgHandle      *handle,
 										   GError         **error);
 GdkPixbuf  *rsvg_handle_get_pixbuf        (RsvgHandle      *handle);
 GdkPixbuf  *rsvg_handle_get_pixbuf_sub    (RsvgHandle *handle, const char * id);
-void        rsvg_handle_free              (RsvgHandle      *handle);
 
 G_CONST_RETURN char *
 rsvg_handle_get_base_uri (RsvgHandle *handle);
@@ -84,6 +120,10 @@ RsvgHandle * rsvg_handle_new_from_data (const guint8 *data,
 RsvgHandle * rsvg_handle_new_from_file (const gchar *file_name,
 										GError **error);
 
+#ifndef RSVG_DISABLE_DEPRECATED
+
+void        rsvg_handle_free              (RsvgHandle      *handle);
+
 /**
  * RsvgSizeFunc ():
  * @width: Pointer to where to set/store the width
@@ -94,6 +134,8 @@ RsvgHandle * rsvg_handle_new_from_file (const gchar *file_name,
  * @width: the ouput width the SVG should be
  * @height: the output height the SVG should be
  * @user_data: user data
+ *
+ * Deprecated: Set up a cairo matrix and use rsvg_cairo_render() instead.
  */
 typedef void (* RsvgSizeFunc) (gint     *width,
 							   gint     *height,
@@ -103,7 +145,7 @@ void        rsvg_handle_set_size_callback (RsvgHandle      *handle,
 										   gpointer         user_data,
 										   GDestroyNotify   user_data_destroy);
 
-/* Convenience API */
+/* GdkPixbuf convenience API */
 
 GdkPixbuf  *rsvg_pixbuf_from_file                  (const gchar  *file_name,
 													GError      **error);
@@ -125,6 +167,9 @@ GdkPixbuf  *rsvg_pixbuf_from_file_at_zoom_with_max (const gchar  *file_name,
 													gint          max_width,
 													gint          max_height,
 													GError      **error);
+
+#endif /* RSVG_DISABLE_DEPRECATED */
+
 G_END_DECLS
 
 #endif /* RSVG_H */
